FROM dimti/workspace:7.4

###########################################################################
# Laradock non-root user:
###########################################################################

ARG CUSTOM_PUID=1000
ENV PUID ${CUSTOM_PUID}
ARG CUSTOM_PGID=1000
ENV PGID ${CUSTOM_PGID}

RUN usermod -u ${CUSTOM_PUID} laradock && groupmod -g ${CUSTOM_PGID} laradock

RUN chown -R ${CUSTOM_PUID}:${CUSTOM_PGID} /home/laradock

###########################################################################
# Set Timezone
###########################################################################

ARG CUSTOM_TZ=Europe/Moscow
ENV TZ ${CUSTOM_TZ}

RUN ln -snf /usr/share/zoneinfo/$CUSTOM_TZ /etc/localtime && echo $CUSTOM_TZ > /etc/timezone

###########################################################################
# Additional PHP-extensions:
###########################################################################

#RUN pecl install igbinary && pecl install -a redis
RUN pecl install -a redis

RUN echo "extension=redis.so" > /etc/php/7.4/cli/conf.d/20-redis.ini

###########################################################################
# S3 config
###########################################################################

USER laradock

COPY ./minio/auth.json /home/laradock/.mc/config.json

###########################################################################
# Install custom node version
###########################################################################

USER root

ARG CUSTOM_NODE_VERSION
ENV CUSTOM_NODE_VERSION ${CUSTOM_NODE_VERSION}

RUN if [ ! -z "${CUSTOM_NODE_VERSION}" ]; then \
    . ~/.bashrc && nvm install ${CUSTOM_NODE_VERSION} \
    && . ~/.bashrc && nvm alias default ${CUSTOM_NODE_VERSION} \
    && cp -R ~/.nvm/alias /home/laradock/.nvm \
    && cp -R ~/.nvm/versions /home/laradock/.nvm \
    && chown -R ${CUSTOM_PUID}:${CUSTOM_PGID} /home/laradock/.nvm \
;fi

###########################################################################
# Remove DST_Root_CA3
###########################################################################

RUN sed -i 's/^mozilla\/DST_Root_CA_X3\.crt/!mozilla\/DST_Root_CA_X3.crt/g'  /etc/ca-certificates.conf && update-ca-certificates

###########################################################################
# Crontab
###########################################################################

USER root

COPY ./crontab74 /etc/cron.d

RUN chmod -R 644 /etc/cron.d